==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/GLOBALTEXTCHANGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GLOBALTEXTCHANGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GLOBALTEXTCHANGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTPOOL"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTLENGTH"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLOBALTEXTCHANGEID_Type", propOrder = {
    "languageid",
    "boilertextpool",
    "boilertextlength"
})
public class GLOBALTEXTCHANGEID_Type {

    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;
    @XmlElement(name = "BOILERTEXTPOOL", required = true)
    protected String boilertextpool;
    @XmlElement(name = "BOILERTEXTLENGTH")
    protected long boilertextlength;

    /**
     * Obtient la valeur de la propriété languageid.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Définit la valeur de la propriété languageid.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

    /**
     * Obtient la valeur de la propriété boilertextpool.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBOILERTEXTPOOL() {
        return boilertextpool;
    }

    /**
     * Définit la valeur de la propriété boilertextpool.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBOILERTEXTPOOL(String value) {
        this.boilertextpool = value;
    }

    /**
     * Obtient la valeur de la propriété boilertextlength.
     * 
     */
    public long getBOILERTEXTLENGTH() {
        return boilertextlength;
    }

    /**
     * Définit la valeur de la propriété boilertextlength.
     * 
     */
    public void setBOILERTEXTLENGTH(long value) {
        this.boilertextlength = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/GLOBALTEXTCHANGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GLOBALTEXTCHANGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GLOBALTEXTCHANGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTPOOL"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOILERTEXTLENGTH"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLOBALTEXTCHANGEID_Type", propOrder = {
    "languageid",
    "boilertextpool",
    "boilertextlength"
})
public class GLOBALTEXTCHANGEID_Type {

    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;
    @XmlElement(name = "BOILERTEXTPOOL", required = true)
    protected String boilertextpool;
    @XmlElement(name = "BOILERTEXTLENGTH")
    protected long boilertextlength;

    /**
     * Gets the value of the languageid property.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Sets the value of the languageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

    /**
     * Gets the value of the boilertextpool property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBOILERTEXTPOOL() {
        return boilertextpool;
    }

    /**
     * Sets the value of the boilertextpool property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBOILERTEXTPOOL(String value) {
        this.boilertextpool = value;
    }

    /**
     * Gets the value of the boilertextlength property.
     * 
     */
    public long getBOILERTEXTLENGTH() {
        return boilertextlength;
    }

    /**
     * Sets the value of the boilertextlength property.
     * 
     */
    public void setBOILERTEXTLENGTH(long value) {
        this.boilertextlength = value;
    }

}
